@@ -1,5 +1,5 @@
 ## mainWindow.py - Contains the main UI for system-config-samba
-## Copyright (C) 2002, 2003 Red Hat, Inc.
+## Copyright (C) 2002 - 2007 Red Hat, Inc.
 ## Copyright (C) 2002, 2003 Brent Fox <bfox@redhat.com>
 
 ## This program is free software; you can redistribute it and/or modify
@@ -16,6 +16,9 @@
 ## along with this program; if not, write to the Free Software
 ## Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
+## Authors:
+## Brent Fox <bfox@redhat.com>
+## Nils Philippsen <nphilipp@redhat.com>
 
 import sambaBackend
 import sambaParser
@@ -471,12 +474,16 @@ class MainWindow:
         dlg.destroy()
 
     def onHelpClicked(self, *args):
-        help_page = "file:///usr/share/doc/system-config-samba-" + "@VERSION@" + "/index.html"
-        path = "/usr/bin/htmlview"
+        help_page = "ghelp:system-config-samba"
+        paths = ["/usr/bin/yelp", None]
+
+        for path in paths:
+            if path and os.access (path, os.X_OK):
+                break
         
         if path == None:
             dlg = gtk.MessageDialog(None, 0, gtk.MESSAGE_WARNING, gtk.BUTTONS_OK,
-                                    (_("Help is not available.")))
+                                    (_("The help viewer could not be found. To be able to view help you need to install the 'yelp' package.")))
             dlg.set_position(gtk.WIN_POS_CENTER)
             dlg.run()
             dlg.destroy()
